glue\_genes.glue\_genomics\_data.bed\_factory.read\_bed
=======================================================

.. currentmodule:: glue_genes.glue_genomics_data.bed_factory

.. autofunction:: read_bed